import Callback from "../Helpers/Callback";
import type HasCallbackData from "../Interfaces/HasCallbackData";
import type IsAction from "../Interfaces/IsAction";

/**
 * Alert action
 * 
 * @since 1.0.0
 */
export default class ActionCallback implements IsAction {
    /**
     * Callback data.
     * 
     * @since 1.0.0
     */
    private callback: Callback; 

    /**
    * Constuctor.
    * 
    * @param data Callback data 
    * 
    * @since 1.0.0
    */
    public constructor(callbackData: HasCallbackData) {
        this.callback = new Callback(callbackData);
    }

    /**
     * Run action.
     * 
     * @return boolean True if action was executed successfully.
     * 
     * @since 1.0.0
     */
    public execute() : boolean {
        let returnValue = this.callback.execute();

        if( returnValue === false ) {
            return false;
        }
        
        return true;
    }
}