import type Action from "../Interfaces/IsAction";
import type HasActionConsoleData from "../Interfaces/HasActionConsoleData";

/**
 * Alert action
 * 
 * @since 1.0.0
 */
export default class ActionConsole implements Action {
    /**
     * Action data.
     * 
     * @since 1.0.0
     */
    private data: HasActionConsoleData;

    /**
    * Constuctor.
    * 
    * @param form Form object.
    * @param data Action data.
    * 
    * @since 1.0.0
    */
    public constructor(data: HasActionConsoleData) {
        this.data = data;
    }

    /**
     * Run action.
     * 
     * @return boolean True if action was executed successfully.
     * 
     * @since 1.0.0
     */
    public execute() : boolean {
        switch( this.data.type ) {
            case 'warn':
                console.warn(this.data.message);
                break;
            case 'error':
                console.error(this.data.message);
                break;
            default:
                console.log(this.data.message);
                break;
        }

        return true;
    }
}