import type Action from "$lib/Types/Action";

import type HasActionAlertData from "../Interfaces/HasActionNoticeData";
import type HasActionModalData from "../Interfaces/HasActionModalData";
import type HasActionConsoleData from "../Interfaces/HasActionConsoleData";
import type HasActionNoticeData from "../Interfaces/HasActionNoticeData";
import type HasActionSubmitData from "../Interfaces/HasActionSubmitData";
import type HasCallbackData from "../Interfaces/HasCallbackData";

import ActionAlert from "./ActionAlert";
import ActionCallback from "./ActionCallback";
import ActionConsole from "./ActionConsole";
import ActionModal from "./ActionModal";
import ActionNotice from "./ActionNotice";
import ActionStop from "./ActionStop";
import ActionSubmit from "./ActionSubmit";
import type Form from "../Form/Form";

/**
 * Actions.
 * 
 * @since 1.0.0
 */
export default class Actions {
    private actions: Action[] = [];


    /**
     * Constructor.
     * 
     * @param actionsData Actions data.
     * @param form Form instance.
     * 
     * @since 1.0.0
     */
    public constructor(actionsData: HasActionAlertData[] | HasActionNoticeData[] | HasActionModalData[] | HasCallbackData[], formValues: {} = {} ) {        
        actionsData.forEach(actionData => {
            let action: Action;
            switch (actionData.type) {                
                case "alert":
                    action = new ActionAlert(actionData.data as HasActionAlertData);
                    this.actions.push(action);
                    break;
                case "callback":
                    action = new ActionCallback(actionData.data as HasCallbackData);
                    this.actions.push(action);
                    break;
                case "console":
                    action = new ActionConsole(actionData.data as HasActionConsoleData);
                    this.actions.push(action);
                    break;             
                case "modal":
                    action = new ActionModal(actionData.data as HasActionModalData);
                    this.actions.push(action);
                    break;
                case "notice":
                    action = new ActionNotice(actionData.data as HasActionNoticeData);
                    this.actions.push(action);
                    break;              
                case "stop":
                    action = new ActionStop();
                    this.actions.push(action);
                    break;
                case "submit":
                    action = new ActionSubmit(actionData.data as HasActionSubmitData, formValues);
                    this.actions.push(action);
                    break;
                default:
                    throw new Error("Action type '" + actionData.type + "' does not exist.");
            }
        });
    }

    /**
     * Run all actions.
     * 
     * @return boolean True if all actions were executed successfully.
     * 
     * @since 1.0.0
     */
    public execute(): boolean {
        let execute = true;
        this.actions.forEach(action => {
            if (execute) {
                execute = action.execute();
            }
        } );

        return execute;
    }
}