import type Trigger from "$lib/Types/Trigger";
import type HasEventData from "../Interfaces/HasEventData";
import Event from "./Event";

/**
 * Triggers.
 * 
 * @since 1.0.0
 */
export default class Events {
    private events: Event[] = [];

    /**
     * Constructor.
     * 
     * @param cssClasses Array of CSS classes.
     * 
     * @since 1.0.0
     */
    public constructor(EventsData: HasEventData[], formValues: {} = {}) {
        EventsData?.forEach(eventData => {
            this.events.push(new Event(eventData, formValues));
        });
    }

    /**
     * Chek if there are any events.
     * 
     * @returns boolean True if there are events.
     * 
     * @since 1.0.0
     */
    public exists() : boolean {
        return this.events.length > 0;
    }

    /**
     * Execute all triggers.
     * 
     * @return boolean True if all actions were executed successfully.
     * 
     * @since 1.0.0
     */
    public execute(trigger: Trigger) : boolean {
        let execute = true;
        this.events.forEach(event => {
            if( event.trigger !== trigger ) {
                return;
            }

            if( execute ) {
                execute = event.execute();
            }
        });

        return execute;
    }
}