import Button from "../Helpers/Button";
import type HasActionModalData from "../Interfaces/HasActionModalData";

/**
 * Modal class.
 * 
 * @since 1.0.0
 */
export default class Modal {
    private modalData: HasActionModalData;

    /**
     * Show modal.
     * 
     * @param modalData Modal data.
     * 
     * @since 1.0.0
     */
    public constructor(modalData: HasActionModalData = null) {
        this.modalData = modalData;
    }

    /**
     * Is modal visible.
     * 
     * @returns True if modal is visible, false otherwise.
     * 
     * @since 1.0.0
     */
    public isVisible(): boolean {
        return this.modalData !== null && this.modalData.visibility === "show";
    }

    /**
     * Modal title.
     * 
     * @returns Modal title.
     * 
     * @since 1.0.0
     */
    public getTitle(): string {
        return this.modalData.title;
    }

    /**
     * Modal body.
     * 
     * @returns Modal body.
     * 
     * @since 1.0.0
     */
    public getBody(): string {
        return this.modalData.body;
    }

    /**
     * Get buttons.
     * 
     * @returns Modal buttons.
     * 
     * @since 1.0.0
     */
    public getButtons(): Button[] {
        let buttons: Button[] = [];

        this.modalData.buttons.forEach(buttonData => {
            buttons.push(new Button(buttonData));            
        });

        return buttons;
    }

    /**
     * Hide modal.
     * 
     * @since 1.0.0
     */
    public dismiss(): void {
        this.modalData = null;
    }

    /**
     * Check if modal exists.
     * 
     * @since 1.0.0
     */
    public exists(): boolean {
        return this.modalData !== undefined;
    }
}