import type HasFieldsetData from '../Interfaces/HasFieldsetData';
import CSSClasses from '../Helpers/CSSClasses';
import Conditions from '../Helpers/Conditions';
import type HasFieldData from '../Interfaces/HasFieldData';
import MultipleField from '../Fields/MultipleField';
import SingleField from '../Fields/SingleField';
import type Field from '../Fields/Field';

/**
 * Class Fieldset.
 * 
 * @since 1.0.0
 */
export default class Fieldset {
    readonly id: string;
    readonly legend: string;    
    readonly fields: (SingleField | MultipleField)[] = [];

    readonly nextFieldset: string;
    readonly prevFieldset: string;
        
    readonly conditions: Conditions;
    readonly classes: CSSClasses;
    readonly legendClasses: CSSClasses;
    readonly fieldsClasses: CSSClasses;

    /**
     * Constructor.
     * 
     * @param form Form object.
     * 
     * @since 1.0.0
     */
    public constructor(fieldsetData: HasFieldsetData, formValues: {} = {}) {
        this.id = fieldsetData.id;
        this.legend = fieldsetData.legend;
        this.nextFieldset = fieldsetData.nextFieldset;
        this.prevFieldset = fieldsetData.prevFieldset;

        fieldsetData.fields.forEach((fieldData: HasFieldData) => {
            if( fieldData.multiple === true ) {
                this.fields.push(new MultipleField(fieldData, formValues));
            } else {
                this.fields.push(new SingleField(fieldData, formValues));
            }
        });

        this.conditions = new Conditions(fieldsetData.conditions, formValues);
        this.classes = new CSSClasses(fieldsetData.classes);
        this.legendClasses = new CSSClasses(fieldsetData.legendClasses);
        this.fieldsClasses = new CSSClasses(fieldsetData.fieldsClasses);
    }

    public hasNext(): boolean {
        return this.nextFieldset !== undefined;
    }

    public hasPrev(): boolean {
        return this.prevFieldset !== undefined;
    }
}