import type HasButtonData from "../Interfaces/HasButtonData";

/**
 * Button class.
 * 
 * @since 1.0.0
 */
export default class Button {
    /**
     * Constructor.
     * 
     * @param buttonData Button data.
     * 
     * @since 1.0.0
     */
    public constructor(private buttonData: HasButtonData) { }

    /**
     * Get button label.
     * 
     * @returns Label of button.
     * 
     * @since 1.0.0
     */
    public getLabel(): string {
        return this.buttonData.label;
    }

    /**
     * Get method name of callback.
     * 
     * @returns 
     * 
     * @since 1.0.0
     */
    public getMethod(): string {
        return this.buttonData.callback.method;
    }

    /**
     * Fires button callback.
     * 
     * @since 1.0.0
     */
    public click(dismiss): void {
        const methodName = this.buttonData.callback.method;
        const params = this.buttonData.callback.args;
        
        if (methodName === "dismiss") {
            dismiss();
        }else{
            const method = window[methodName];
            method.apply(window, params !== undefined ? params : []);
        }
    }
}