/**
 * CSSClasses.
 * 
 * @since 1.0.0
 */
export default class CSSClasses {
    /**
     * Constructor.
     * 
     * @param cssClasses Array of CSS classes.
     * 
     * @since 1.0.0
     */
    public constructor(
        private cssClasses: string[] = []
    ){}

    /**
     * Get CSS classes.
     * 
     * @returns CSS classes array.
     * 
     * @since 1.0.0
     */
    public get(): string[] {
        return this.cssClasses;
    }

    /**
     * Get classes string for HTML parameter.
     * 
     * @returns CSS classes in a string.
     * 
     * @since 1.0.0
     */
    public toString(): string {
        if( Array.isArray(this.cssClasses)) {
            return this.cssClasses.join(' ');
        }
        
        console.error( "CSS Classes have to be array. Current value:", this.cssClasses );
    }

    /**
     * Add CSS class.
     * 
     * @param name Name of CSS class to add.
     * 
     * @since 1.0.0
     */
    public add(name: string) {
        this.cssClasses.push(name);
    }

    /**
     * Remove CSS class.
     * 
     * @param name Name of CSS class to remove.
     * 
     * @since 1.0.0
     */
    public remove(name: string){
        this.cssClasses = this.cssClasses.filter( className => className !== name );
    }
}