import type HasCallbackData from "../Interfaces/HasCallbackData";

/**
 * Callback class.
 * 
 * @since 1.0.0
 */
export default class Callback {
    /**
     * Callback method.
     * 
     * @type {string}
     * 
     * @since 1.0.0
     */
    protected method: string;

    /**
     * Callback arguments.
     * 
     * @type {Array}
     * 
     * @since 1.0.0
     */
    protected args: any[];

    /**
     * Constructor.
     * 
     * @param method Callback method.
     * @param args Callback arguments.
     * 
     * @since 1.0.0
     */
    public constructor(callback: HasCallbackData) {
        this.method = callback.method;

        if( callback.args !== undefined ) {
            this.args = callback.args.slice();
        } else {
            this.args = [];
        }
    }

    /**
     * Execute callback.
     * 
     * @returns any Callback return value.
     * 
     * @since 1.0.0
     */
    public execute(): any {
        if( globalThis[this.method] === undefined ) {
            console.error(`Callback "${this.method}" does not exist.`);
            return;
        }

        let returnValue;
        if( this.args.length > 0 ) {
            returnValue = globalThis[this.method](...this.args);
        } else {
            returnValue = globalThis[this.method]();
        }

        return returnValue;
    }
}